==> haskell-cryptohash-conduit-0.1.1-220-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-conduit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-conduit
version: 0.1.1
id: cryptohash-conduit-0.1.1-H52jR0lW3WnF9cYmST5Bta
key: cryptohash-conduit-0.1.1-H52jR0lW3WnF9cYmST5Bta
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-cryptohash-conduit
synopsis: cryptohash conduit
description:
    Support all the @cryptohash@ package using conduits from
    the @conduit@ package.
category: Cryptography, Conduit
abi: 262fe399814cd7320c2b79ce2c01b35a
exposed: True
exposed-modules:
    Crypto.Hash.Conduit
import-dirs: /usr/lib/ghc-8.4.3/site-local/cryptohash-conduit-0.1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/cryptohash-conduit-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/cryptohash-conduit-0.1.1
hs-libraries: HScryptohash-conduit-0.1.1-H52jR0lW3WnF9cYmST5Bta
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    conduit-1.3.0.3-21oVxbuLudTDFRaDyFHkw4
    resourcet-1.2.1-3KYZBJL4a2rBVLKWvBKB4Q
    conduit-extra-1.3.0-IsNBoNLATEi80mj4mxpJy
    cryptohash-0.11.9-HjLcGiIxEFW8kOSZVaJ9pE transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             conduit-1.3.0.3-21oVxbuLudTDFRaDyFHkw4=a446a7a16dc9f46b5e22956d60c75c44
             resourcet-1.2.1-3KYZBJL4a2rBVLKWvBKB4Q=b5273090c64c1efd0c4504885cc2bdef
             conduit-extra-1.3.0-IsNBoNLATEi80mj4mxpJy=548e65ec504a59b6f79c6f732bd1fe14
             cryptohash-0.11.9-HjLcGiIxEFW8kOSZVaJ9pE=60774213ec4b880ec762bba3862dd227
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-cryptohash-conduit/html/cryptohash-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-conduit-0.1.1-231-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-conduit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-conduit
version: 0.1.1
id: cryptohash-conduit-0.1.1-Gd1nAZAB2mjVtid6ooNym
key: cryptohash-conduit-0.1.1-Gd1nAZAB2mjVtid6ooNym
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-cryptohash-conduit
synopsis: cryptohash conduit
description:
    Support all the @cryptohash@ package using conduits from
    the @conduit@ package.
category: Cryptography, Conduit
abi: 4b33db696df0b371d79d94f5530a05b8
exposed: True
exposed-modules:
    Crypto.Hash.Conduit
import-dirs: /usr/lib/ghc-8.6.1/site-local/cryptohash-conduit-0.1.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/cryptohash-conduit-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/cryptohash-conduit-0.1.1
hs-libraries: HScryptohash-conduit-0.1.1-Gd1nAZAB2mjVtid6ooNym
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1-2hedDM8RkfyGc8ZcxJJZlx
    conduit-extra-1.3.0-1Q6txIz8Dq1JIr871feyRL
    cryptohash-0.11.9-JASsjOOUTMgGhjnbkvXzrx
    resourcet-1.2.2-JdORPBy4ztGDXSSlNDo2w5 transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-cryptohash-conduit/html/cryptohash-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
